@@ -55,29 +55,29 @@ class Document(proto.Message):
         text (str):
             UTF-8 encoded text in reading order from the
             document.
-        text_styles (Sequence[~.document.Document.Style]):
+        text_styles (Sequence[google.cloud.documentai_v1beta2.types.Document.Style]):
             Styles for the
             [Document.text][google.cloud.documentai.v1beta2.Document.text].
-        pages (Sequence[~.document.Document.Page]):
+        pages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page]):
             Visual page layout for the
             [Document][google.cloud.documentai.v1beta2.Document].
-        entities (Sequence[~.document.Document.Entity]):
+        entities (Sequence[google.cloud.documentai_v1beta2.types.Document.Entity]):
             A list of entities detected on
             [Document.text][google.cloud.documentai.v1beta2.Document.text].
             For document shards, entities in this list may cross shard
             boundaries.
-        entity_relations (Sequence[~.document.Document.EntityRelation]):
+        entity_relations (Sequence[google.cloud.documentai_v1beta2.types.Document.EntityRelation]):
             Relationship among
             [Document.entities][google.cloud.documentai.v1beta2.Document.entities].
-        shard_info (~.document.Document.ShardInfo):
+        shard_info (google.cloud.documentai_v1beta2.types.Document.ShardInfo):
             Information about the sharding if this
             document is sharded part of a larger document.
             If the document is not sharded, this message is
             not specified.
-        labels (Sequence[~.document.Document.Label]):
+        labels (Sequence[google.cloud.documentai_v1beta2.types.Document.Label]):
             [Label][google.cloud.documentai.v1beta2.Document.Label]s for
             this document.
-        error (~.status.Status):
+        error (google.rpc.status_pb2.Status):
             Any error that occurred while processing this
             document.
     """
@@ -140,12 +140,12 @@ class Document(proto.Message):
         CSS conventions as much as possible.
 
         Attributes:
-            text_anchor (~.document.Document.TextAnchor):
+            text_anchor (google.cloud.documentai_v1beta2.types.Document.TextAnchor):
                 Text anchor indexing into the
                 [Document.text][google.cloud.documentai.v1beta2.Document.text].
-            color (~.gt_color.Color):
+            color (google.type.color_pb2.Color):
                 Text color.
-            background_color (~.gt_color.Color):
+            background_color (google.type.color_pb2.Color):
                 Text background color.
             font_weight (str):
                 Font weight. Possible values are normal, bold, bolder, and
@@ -156,7 +156,7 @@ class Document(proto.Message):
             text_decoration (str):
                 Text decoration. Follows CSS standard.
                 https://www.w3schools.com/cssref/pr_text_text-decoration.asp
-            font_size (~.document.Document.Style.FontSize):
+            font_size (google.cloud.documentai_v1beta2.types.Document.Style.FontSize):
                 Font size.
         """
 
@@ -204,37 +204,37 @@ class Document(proto.Message):
                 Useful when a page is taken out of a
                 [Document][google.cloud.documentai.v1beta2.Document] for
                 individual processing.
-            dimension (~.document.Document.Page.Dimension):
+            dimension (google.cloud.documentai_v1beta2.types.Document.Page.Dimension):
                 Physical dimension of the page.
-            layout (~.document.Document.Page.Layout):
+            layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                 [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                 for the page.
-            detected_languages (Sequence[~.document.Document.Page.DetectedLanguage]):
+            detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                 A list of detected languages together with
                 confidence.
-            blocks (Sequence[~.document.Document.Page.Block]):
+            blocks (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Block]):
                 A list of visually detected text blocks on
                 the page. A block has a set of lines (collected
                 into paragraphs) that have a common line-spacing
                 and orientation.
-            paragraphs (Sequence[~.document.Document.Page.Paragraph]):
+            paragraphs (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Paragraph]):
                 A list of visually detected text paragraphs
                 on the page. A collection of lines that a human
                 would perceive as a paragraph.
-            lines (Sequence[~.document.Document.Page.Line]):
+            lines (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Line]):
                 A list of visually detected text lines on the
                 page. A collection of tokens that a human would
                 perceive as a line.
-            tokens (Sequence[~.document.Document.Page.Token]):
+            tokens (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Token]):
                 A list of visually detected tokens on the
                 page.
-            visual_elements (Sequence[~.document.Document.Page.VisualElement]):
+            visual_elements (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.VisualElement]):
                 A list of detected non-text visual elements
                 e.g. checkbox, signature etc. on the page.
-            tables (Sequence[~.document.Document.Page.Table]):
+            tables (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Table]):
                 A list of visually detected tables on the
                 page.
-            form_fields (Sequence[~.document.Document.Page.FormField]):
+            form_fields (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.FormField]):
                 A list of visually detected form fields on
                 the page.
         """
@@ -261,7 +261,7 @@ class Document(proto.Message):
             r"""Visual element describing a layout unit on a page.
 
             Attributes:
-                text_anchor (~.document.Document.TextAnchor):
+                text_anchor (google.cloud.documentai_v1beta2.types.Document.TextAnchor):
                     Text anchor indexing into the
                     [Document.text][google.cloud.documentai.v1beta2.Document.text].
                 confidence (float):
@@ -270,10 +270,10 @@ class Document(proto.Message):
                     within context of the object this layout is for. e.g.
                     confidence can be for a single token, a table, a visual
                     element, etc. depending on context. Range [0, 1].
-                bounding_poly (~.geometry.BoundingPoly):
+                bounding_poly (google.cloud.documentai_v1beta2.types.BoundingPoly):
                     The bounding polygon for the
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout].
-                orientation (~.document.Document.Page.Layout.Orientation):
+                orientation (google.cloud.documentai_v1beta2.types.Document.Page.Layout.Orientation):
                     Detected orientation for the
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout].
                 id (str):
@@ -310,11 +310,11 @@ class Document(proto.Message):
             have a common line-spacing and orientation.
 
             Attributes:
-                layout (~.document.Document.Page.Layout):
+                layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for
                     [Block][google.cloud.documentai.v1beta2.Document.Page.Block].
-                detected_languages (Sequence[~.document.Document.Page.DetectedLanguage]):
+                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
@@ -332,11 +332,11 @@ class Document(proto.Message):
             paragraph.
 
             Attributes:
-                layout (~.document.Document.Page.Layout):
+                layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for
                     [Paragraph][google.cloud.documentai.v1beta2.Document.Page.Paragraph].
-                detected_languages (Sequence[~.document.Document.Page.DetectedLanguage]):
+                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
@@ -355,11 +355,11 @@ class Document(proto.Message):
             etc.
 
             Attributes:
-                layout (~.document.Document.Page.Layout):
+                layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for
                     [Line][google.cloud.documentai.v1beta2.Document.Page.Line].
-                detected_languages (Sequence[~.document.Document.Page.DetectedLanguage]):
+                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
@@ -376,14 +376,14 @@ class Document(proto.Message):
             r"""A detected token.
 
             Attributes:
-                layout (~.document.Document.Page.Layout):
+                layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for
                     [Token][google.cloud.documentai.v1beta2.Document.Page.Token].
-                detected_break (~.document.Document.Page.Token.DetectedBreak):
+                detected_break (google.cloud.documentai_v1beta2.types.Document.Page.Token.DetectedBreak):
                     Detected break at the end of a
                     [Token][google.cloud.documentai.v1beta2.Document.Page.Token].
-                detected_languages (Sequence[~.document.Document.Page.DetectedLanguage]):
+                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
@@ -393,7 +393,7 @@ class Document(proto.Message):
                 [Token][google.cloud.documentai.v1beta2.Document.Page.Token].
 
                 Attributes:
-                    type_ (~.document.Document.Page.Token.DetectedBreak.Type):
+                    type_ (google.cloud.documentai_v1beta2.types.Document.Page.Token.DetectedBreak.Type):
                         Detected break type.
                 """
 
@@ -425,14 +425,14 @@ class Document(proto.Message):
             etc. on the page.
 
             Attributes:
-                layout (~.document.Document.Page.Layout):
+                layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for
                     [VisualElement][google.cloud.documentai.v1beta2.Document.Page.VisualElement].
                 type_ (str):
                     Type of the
                     [VisualElement][google.cloud.documentai.v1beta2.Document.Page.VisualElement].
-                detected_languages (Sequence[~.document.Document.Page.DetectedLanguage]):
+                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
@@ -451,15 +451,15 @@ class Document(proto.Message):
             r"""A table representation similar to HTML table structure.
 
             Attributes:
-                layout (~.document.Document.Page.Layout):
+                layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for
                     [Table][google.cloud.documentai.v1beta2.Document.Page.Table].
-                header_rows (Sequence[~.document.Document.Page.Table.TableRow]):
+                header_rows (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Table.TableRow]):
                     Header rows of the table.
-                body_rows (Sequence[~.document.Document.Page.Table.TableRow]):
+                body_rows (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Table.TableRow]):
                     Body rows of the table.
-                detected_languages (Sequence[~.document.Document.Page.DetectedLanguage]):
+                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
@@ -468,7 +468,7 @@ class Document(proto.Message):
                 r"""A row of table cells.
 
                 Attributes:
-                    cells (Sequence[~.document.Document.Page.Table.TableCell]):
+                    cells (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Table.TableCell]):
                         Cells that make up this row.
                 """
 
@@ -480,7 +480,7 @@ class Document(proto.Message):
                 r"""A cell representation inside the table.
 
                 Attributes:
-                    layout (~.document.Document.Page.Layout):
+                    layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                         [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                         for
                         [TableCell][google.cloud.documentai.v1beta2.Document.Page.Table.TableCell].
@@ -488,7 +488,7 @@ class Document(proto.Message):
                         How many rows this cell spans.
                     col_span (int):
                         How many columns this cell spans.
-                    detected_languages (Sequence[~.document.Document.Page.DetectedLanguage]):
+                    detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                         A list of detected languages together with
                         confidence.
                 """
@@ -525,21 +525,21 @@ class Document(proto.Message):
             r"""A form field detected on the page.
 
             Attributes:
-                field_name (~.document.Document.Page.Layout):
+                field_name (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for the
                     [FormField][google.cloud.documentai.v1beta2.Document.Page.FormField]
                     name. e.g. ``Address``, ``Email``, ``Grand total``,
                     ``Phone number``, etc.
-                field_value (~.document.Document.Page.Layout):
+                field_value (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for the
                     [FormField][google.cloud.documentai.v1beta2.Document.Page.FormField]
                     value.
-                name_detected_languages (Sequence[~.document.Document.Page.DetectedLanguage]):
+                name_detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages for name
                     together with confidence.
-                value_detected_languages (Sequence[~.document.Document.Page.DetectedLanguage]):
+                value_detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages for value
                     together with confidence.
                 value_type (str):
@@ -640,7 +640,7 @@ class Document(proto.Message):
         person, an organization, or location.
 
         Attributes:
-            text_anchor (~.document.Document.TextAnchor):
+            text_anchor (google.cloud.documentai_v1beta2.types.Document.TextAnchor):
                 Provenance of the entity. Text anchor indexing into the
                 [Document.text][google.cloud.documentai.v1beta2.Document.text].
             type_ (str):
@@ -652,14 +652,14 @@ class Document(proto.Message):
             confidence (float):
                 Optional. Confidence of detected Schema entity. Range [0,
                 1].
-            page_anchor (~.document.Document.PageAnchor):
+            page_anchor (google.cloud.documentai_v1beta2.types.Document.PageAnchor):
                 Optional. Represents the provenance of this
                 entity wrt. the location on the page where it
                 was found.
             id (str):
                 Optional. Canonical id. This will be a unique
                 value in the entity list for this document.
-            bounding_poly_for_demo_frontend (~.geometry.BoundingPoly):
+            bounding_poly_for_demo_frontend (google.cloud.documentai_v1beta2.types.BoundingPoly):
                 Optional. Temporary field to store the
                 bounding poly for short-term POCs. Used by the
                 frontend only. Do not use before you talk to
@@ -712,7 +712,7 @@ class Document(proto.Message):
         [Document.text][google.cloud.documentai.v1beta2.Document.text].
 
         Attributes:
-            text_segments (Sequence[~.document.Document.TextAnchor.TextSegment]):
+            text_segments (Sequence[google.cloud.documentai_v1beta2.types.Document.TextAnchor.TextSegment]):
                 The text segments from the
                 [Document.text][google.cloud.documentai.v1beta2.Document.text].
         """
@@ -748,7 +748,7 @@ class Document(proto.Message):
         [Document.pages][google.cloud.documentai.v1beta2.Document.pages].
 
         Attributes:
-            page_refs (Sequence[~.document.Document.PageAnchor.PageRef]):
+            page_refs (Sequence[google.cloud.documentai_v1beta2.types.Document.PageAnchor.PageRef]):
                 One or more references to visual page
                 elements
         """
@@ -762,7 +762,7 @@ class Document(proto.Message):
                     Required. Index into the
                     [Document.pages][google.cloud.documentai.v1beta2.Document.pages]
                     element
-                layout_type (~.document.Document.PageAnchor.PageRef.LayoutType):
+                layout_type (google.cloud.documentai_v1beta2.types.Document.PageAnchor.PageRef.LayoutType):
                     Optional. The type of the layout element that
                     is being referenced.  If not specified the whole
                     page is assumed to be referenced.
