@@ -51,9 +51,91 @@ class DocumentProcessorServiceAsyncClient:
     DEFAULT_ENDPOINT = DocumentProcessorServiceClient.DEFAULT_ENDPOINT
     DEFAULT_MTLS_ENDPOINT = DocumentProcessorServiceClient.DEFAULT_MTLS_ENDPOINT
 
-    from_service_account_file = DocumentProcessorServiceClient.from_service_account_file
+    human_review_config_path = staticmethod(
+        DocumentProcessorServiceClient.human_review_config_path
+    )
+    parse_human_review_config_path = staticmethod(
+        DocumentProcessorServiceClient.parse_human_review_config_path
+    )
+    processor_path = staticmethod(DocumentProcessorServiceClient.processor_path)
+    parse_processor_path = staticmethod(
+        DocumentProcessorServiceClient.parse_processor_path
+    )
+
+    common_billing_account_path = staticmethod(
+        DocumentProcessorServiceClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        DocumentProcessorServiceClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(DocumentProcessorServiceClient.common_folder_path)
+    parse_common_folder_path = staticmethod(
+        DocumentProcessorServiceClient.parse_common_folder_path
+    )
+
+    common_organization_path = staticmethod(
+        DocumentProcessorServiceClient.common_organization_path
+    )
+    parse_common_organization_path = staticmethod(
+        DocumentProcessorServiceClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(
+        DocumentProcessorServiceClient.common_project_path
+    )
+    parse_common_project_path = staticmethod(
+        DocumentProcessorServiceClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(
+        DocumentProcessorServiceClient.common_location_path
+    )
+    parse_common_location_path = staticmethod(
+        DocumentProcessorServiceClient.parse_common_location_path
+    )
+
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            DocumentProcessorServiceAsyncClient: The constructed client.
+        """
+        return DocumentProcessorServiceClient.from_service_account_info.__func__(DocumentProcessorServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+        file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            DocumentProcessorServiceAsyncClient: The constructed client.
+        """
+        return DocumentProcessorServiceClient.from_service_account_file.__func__(DocumentProcessorServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> DocumentProcessorServiceTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            DocumentProcessorServiceTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(DocumentProcessorServiceClient).get_transport_class,
         type(DocumentProcessorServiceClient),
@@ -119,12 +201,13 @@ class DocumentProcessorServiceAsyncClient:
         r"""Processes a single document.
 
         Args:
-            request (:class:`~.document_processor_service.ProcessRequest`):
+            request (:class:`google.cloud.documentai_v1beta3.types.ProcessRequest`):
                 The request object. Request message for the process
                 document method.
             name (:class:`str`):
                 Required. The processor resource
                 name.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -136,7 +219,7 @@ class DocumentProcessorServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.document_processor_service.ProcessResponse:
+            google.cloud.documentai_v1beta3.types.ProcessResponse:
                 Response message for the process
                 document method.
 
@@ -144,7 +227,8 @@ class DocumentProcessorServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -167,8 +251,9 @@ class DocumentProcessorServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=120.0,
             ),
             default_timeout=120.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -199,12 +284,13 @@ class DocumentProcessorServiceAsyncClient:
         written to Cloud Storage as JSON in the [Document] format.
 
         Args:
-            request (:class:`~.document_processor_service.BatchProcessRequest`):
+            request (:class:`google.cloud.documentai_v1beta3.types.BatchProcessRequest`):
                 The request object. Request message for batch process
                 document method.
             name (:class:`str`):
                 Required. The processor resource
                 name.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -216,18 +302,19 @@ class DocumentProcessorServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.document_processor_service.BatchProcessResponse``:
+                :class:`google.cloud.documentai_v1beta3.types.BatchProcessResponse`
                 Response message for batch process document method.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -250,8 +337,9 @@ class DocumentProcessorServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=120.0,
             ),
             default_timeout=120.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -290,13 +378,14 @@ class DocumentProcessorServiceAsyncClient:
         should be processed by the specified processor.
 
         Args:
-            request (:class:`~.document_processor_service.ReviewDocumentRequest`):
+            request (:class:`google.cloud.documentai_v1beta3.types.ReviewDocumentRequest`):
                 The request object. Request message for review document
                 method.
             human_review_config (:class:`str`):
                 Required. The resource name of the
                 HumanReviewConfig that the document will
                 be reviewed with.
+
                 This corresponds to the ``human_review_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -308,18 +397,19 @@ class DocumentProcessorServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.document_processor_service.ReviewDocumentResponse``:
+                :class:`google.cloud.documentai_v1beta3.types.ReviewDocumentResponse`
                 Response message for review document method.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([human_review_config]):
+        has_flattened_params = any([human_review_config])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -342,8 +432,9 @@ class DocumentProcessorServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=120.0,
             ),
             default_timeout=120.0,
             client_info=DEFAULT_CLIENT_INFO,
