@@ -119,6 +119,22 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            DocumentProcessorServiceClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
@@ -131,7 +147,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            DocumentProcessorServiceClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -139,6 +155,106 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> DocumentProcessorServiceTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            DocumentProcessorServiceTransport: The transport used by the client instance.
+        """
+        return self._transport
+
+    @staticmethod
+    def human_review_config_path(project: str, location: str, processor: str,) -> str:
+        """Return a fully-qualified human_review_config string."""
+        return "projects/{project}/locations/{location}/processors/{processor}/humanReviewConfig".format(
+            project=project, location=location, processor=processor,
+        )
+
+    @staticmethod
+    def parse_human_review_config_path(path: str) -> Dict[str, str]:
+        """Parse a human_review_config path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/processors/(?P<processor>.+?)/humanReviewConfig$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def processor_path(project: str, location: str, processor: str,) -> str:
+        """Return a fully-qualified processor string."""
+        return "projects/{project}/locations/{location}/processors/{processor}".format(
+            project=project, location=location, processor=processor,
+        )
+
+    @staticmethod
+    def parse_processor_path(path: str) -> Dict[str, str]:
+        """Parse a processor path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/processors/(?P<processor>.+?)$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_billing_account_path(billing_account: str,) -> str:
+        """Return a fully-qualified billing_account string."""
+        return "billingAccounts/{billing_account}".format(
+            billing_account=billing_account,
+        )
+
+    @staticmethod
+    def parse_common_billing_account_path(path: str) -> Dict[str, str]:
+        """Parse a billing_account path into its component segments."""
+        m = re.match(r"^billingAccounts/(?P<billing_account>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_folder_path(folder: str,) -> str:
+        """Return a fully-qualified folder string."""
+        return "folders/{folder}".format(folder=folder,)
+
+    @staticmethod
+    def parse_common_folder_path(path: str) -> Dict[str, str]:
+        """Parse a folder path into its component segments."""
+        m = re.match(r"^folders/(?P<folder>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_organization_path(organization: str,) -> str:
+        """Return a fully-qualified organization string."""
+        return "organizations/{organization}".format(organization=organization,)
+
+    @staticmethod
+    def parse_common_organization_path(path: str) -> Dict[str, str]:
+        """Parse a organization path into its component segments."""
+        m = re.match(r"^organizations/(?P<organization>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_project_path(project: str,) -> str:
+        """Return a fully-qualified project string."""
+        return "projects/{project}".format(project=project,)
+
+    @staticmethod
+    def parse_common_project_path(path: str) -> Dict[str, str]:
+        """Parse a project path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_location_path(project: str, location: str,) -> str:
+        """Return a fully-qualified location string."""
+        return "projects/{project}/locations/{location}".format(
+            project=project, location=location,
+        )
+
+    @staticmethod
+    def parse_common_location_path(path: str) -> Dict[str, str]:
+        """Parse a location path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
+        return m.groupdict() if m else {}
+
     def __init__(
         self,
         *,
@@ -155,10 +271,10 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.DocumentProcessorServiceTransport]): The
+            transport (Union[str, DocumentProcessorServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -174,10 +290,10 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 not provided, the default SSL client certificate will be used if
                 present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                 set, no client certificate will be used.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
 
         Raises:
@@ -194,21 +310,17 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                client_cert_source_func = (
+                    mtls.default_client_cert_source() if is_mtls else None
+                )
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -251,7 +363,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -268,12 +380,13 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         r"""Processes a single document.
 
         Args:
-            request (:class:`~.document_processor_service.ProcessRequest`):
+            request (google.cloud.documentai_v1beta3.types.ProcessRequest):
                 The request object. Request message for the process
                 document method.
-            name (:class:`str`):
+            name (str):
                 Required. The processor resource
                 name.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -285,7 +398,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 sent along with the request as metadata.
 
         Returns:
-            ~.document_processor_service.ProcessResponse:
+            google.cloud.documentai_v1beta3.types.ProcessResponse:
                 Response message for the process
                 document method.
 
@@ -342,12 +455,13 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         written to Cloud Storage as JSON in the [Document] format.
 
         Args:
-            request (:class:`~.document_processor_service.BatchProcessRequest`):
+            request (google.cloud.documentai_v1beta3.types.BatchProcessRequest):
                 The request object. Request message for batch process
                 document method.
-            name (:class:`str`):
+            name (str):
                 Required. The processor resource
                 name.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -359,11 +473,11 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.document_processor_service.BatchProcessResponse``:
+                :class:`google.cloud.documentai_v1beta3.types.BatchProcessResponse`
                 Response message for batch process document method.
 
         """
@@ -427,13 +541,14 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         should be processed by the specified processor.
 
         Args:
-            request (:class:`~.document_processor_service.ReviewDocumentRequest`):
+            request (google.cloud.documentai_v1beta3.types.ReviewDocumentRequest):
                 The request object. Request message for review document
                 method.
-            human_review_config (:class:`str`):
+            human_review_config (str):
                 Required. The resource name of the
                 HumanReviewConfig that the document will
                 be reviewed with.
+
                 This corresponds to the ``human_review_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -445,11 +560,11 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.document_processor_service.ReviewDocumentResponse``:
+                :class:`google.cloud.documentai_v1beta3.types.ReviewDocumentResponse`
                 Response message for review document method.
 
         """
