@@ -19,6 +19,7 @@ import proto  # type: ignore
 
 
 from google.cloud.documentai_v1beta3.types import document as gcd_document
+from google.cloud.documentai_v1beta3.types import document_io
 from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
 from google.rpc import status_pb2 as gr_status  # type: ignore
 
@@ -27,6 +28,7 @@ __protobuf__ = proto.module(
     package="google.cloud.documentai.v1beta3",
     manifest={
         "ProcessRequest",
+        "HumanReviewStatus",
         "ProcessResponse",
         "BatchProcessRequest",
         "BatchProcessResponse",
@@ -34,6 +36,7 @@ __protobuf__ = proto.module(
         "ReviewDocumentRequest",
         "ReviewDocumentResponse",
         "ReviewDocumentOperationMetadata",
+        "CommonOperationMetadata",
     },
 )
 
@@ -42,9 +45,13 @@ class ProcessRequest(proto.Message):
     r"""Request message for the process document method.
 
     Attributes:
+        inline_document (google.cloud.documentai_v1beta3.types.Document):
+            An inline document proto.
+        raw_document (google.cloud.documentai_v1beta3.types.RawDocument):
+            A raw document content (bytes).
         name (str):
             Required. The processor resource name.
-        document (~.gcd_document.Document):
+        document (google.cloud.documentai_v1beta3.types.Document):
             The document payload, the [content] and [mime_type] fields
             must be set.
         skip_human_review (bool):
@@ -52,6 +59,14 @@ class ProcessRequest(proto.Message):
             skipped for this request. Default to false.
     """
 
+    inline_document = proto.Field(
+        proto.MESSAGE, number=4, oneof="source", message=gcd_document.Document,
+    )
+
+    raw_document = proto.Field(
+        proto.MESSAGE, number=5, oneof="source", message=document_io.RawDocument,
+    )
+
     name = proto.Field(proto.STRING, number=1)
 
     document = proto.Field(proto.MESSAGE, number=2, message=gcd_document.Document,)
@@ -59,11 +74,44 @@ class ProcessRequest(proto.Message):
     skip_human_review = proto.Field(proto.BOOL, number=3)
 
 
+class HumanReviewStatus(proto.Message):
+    r"""The status of human review on a processed document.
+
+    Attributes:
+        state (google.cloud.documentai_v1beta3.types.HumanReviewStatus.State):
+            The state of human review on the processing
+            request.
+        state_message (str):
+            A message providing more details about the
+            human review state.
+        human_review_operation (str):
+            The name of the operation triggered by the processed
+            document. This field is populated only when the [state] is
+            [HUMAN_REVIEW_IN_PROGRESS]. It has the same response type
+            and metadata as the long running operation returned by
+            [ReviewDocument] method.
+    """
+
+    class State(proto.Enum):
+        r"""The final state of human review on a processed document."""
+        STATE_UNSPECIFIED = 0
+        SKIPPED = 1
+        VALIDATION_PASSED = 2
+        IN_PROGRESS = 3
+        ERROR = 4
+
+    state = proto.Field(proto.ENUM, number=1, enum=State,)
+
+    state_message = proto.Field(proto.STRING, number=2)
+
+    human_review_operation = proto.Field(proto.STRING, number=3)
+
+
 class ProcessResponse(proto.Message):
     r"""Response message for the process document method.
 
     Attributes:
-        document (~.gcd_document.Document):
+        document (google.cloud.documentai_v1beta3.types.Document):
             The document payload, will populate fields
             based on the processor's behavior.
         human_review_operation (str):
@@ -73,12 +121,19 @@ class ProcessResponse(proto.Message):
             has the same response type and metadata as the
             long running operation returned by
             ReviewDocument method.
+        human_review_status (google.cloud.documentai_v1beta3.types.HumanReviewStatus):
+            The status of human review on the processed
+            document.
     """
 
     document = proto.Field(proto.MESSAGE, number=1, message=gcd_document.Document,)
 
     human_review_operation = proto.Field(proto.STRING, number=2)
 
+    human_review_status = proto.Field(
+        proto.MESSAGE, number=3, message="HumanReviewStatus",
+    )
+
 
 class BatchProcessRequest(proto.Message):
     r"""Request message for batch process document method.
@@ -86,11 +141,18 @@ class BatchProcessRequest(proto.Message):
     Attributes:
         name (str):
             Required. The processor resource name.
-        input_configs (Sequence[~.document_processor_service.BatchProcessRequest.BatchInputConfig]):
+        input_configs (Sequence[google.cloud.documentai_v1beta3.types.BatchProcessRequest.BatchInputConfig]):
             The input config for each single document in
             the batch process.
-        output_config (~.document_processor_service.BatchProcessRequest.BatchOutputConfig):
+        output_config (google.cloud.documentai_v1beta3.types.BatchProcessRequest.BatchOutputConfig):
             The overall output config for batch process.
+        input_documents (google.cloud.documentai_v1beta3.types.BatchDocumentsInputConfig):
+            The input documents for batch process.
+        document_output_config (google.cloud.documentai_v1beta3.types.DocumentOutputConfig):
+            The overall output config for batch process.
+        skip_human_review (bool):
+            Whether Human Review feature should be
+            skipped for this request. Default to false.
     """
 
     class BatchInputConfig(proto.Message):
@@ -130,6 +192,16 @@ class BatchProcessRequest(proto.Message):
 
     output_config = proto.Field(proto.MESSAGE, number=3, message=BatchOutputConfig,)
 
+    input_documents = proto.Field(
+        proto.MESSAGE, number=5, message=document_io.BatchDocumentsInputConfig,
+    )
+
+    document_output_config = proto.Field(
+        proto.MESSAGE, number=6, message=document_io.DocumentOutputConfig,
+    )
+
+    skip_human_review = proto.Field(proto.BOOL, number=4)
+
 
 class BatchProcessResponse(proto.Message):
     r"""Response message for batch process document method."""
@@ -139,17 +211,17 @@ class BatchProcessMetadata(proto.Message):
     r"""The long running operation metadata for batch process method.
 
     Attributes:
-        state (~.document_processor_service.BatchProcessMetadata.State):
+        state (google.cloud.documentai_v1beta3.types.BatchProcessMetadata.State):
             The state of the current batch processing.
         state_message (str):
             A message providing more details about the
             current state of processing. For example, the
             error message if the operation is failed.
-        create_time (~.timestamp.Timestamp):
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
             The creation time of the operation.
-        update_time (~.timestamp.Timestamp):
+        update_time (google.protobuf.timestamp_pb2.Timestamp):
             The last update time of the operation.
-        individual_process_statuses (Sequence[~.document_processor_service.BatchProcessMetadata.IndividualProcessStatus]):
+        individual_process_statuses (Sequence[google.cloud.documentai_v1beta3.types.BatchProcessMetadata.IndividualProcessStatus]):
             The list of response details of each
             document.
     """
@@ -175,7 +247,7 @@ class BatchProcessMetadata(proto.Message):
                 batch process is started by take snapshot of that document,
                 since a user can move or change that document during the
                 process.
-            status (~.gr_status.Status):
+            status (google.rpc.status_pb2.Status):
                 The status of the processing of the document.
             output_gcs_destination (str):
                 The output_gcs_destination (in the request as
@@ -188,6 +260,9 @@ class BatchProcessMetadata(proto.Message):
                 has the same response type and metadata as the
                 long running operation returned by
                 ReviewDocument method.
+            human_review_status (google.cloud.documentai_v1beta3.types.HumanReviewStatus):
+                The status of human review on the processed
+                document.
         """
 
         input_gcs_source = proto.Field(proto.STRING, number=1)
@@ -198,6 +273,10 @@ class BatchProcessMetadata(proto.Message):
 
         human_review_operation = proto.Field(proto.STRING, number=4)
 
+        human_review_status = proto.Field(
+            proto.MESSAGE, number=5, message="HumanReviewStatus",
+        )
+
     state = proto.Field(proto.ENUM, number=1, enum=State,)
 
     state_message = proto.Field(proto.STRING, number=2)
@@ -215,14 +294,20 @@ class ReviewDocumentRequest(proto.Message):
     r"""Request message for review document method.
 
     Attributes:
+        inline_document (google.cloud.documentai_v1beta3.types.Document):
+            An inline document proto.
         human_review_config (str):
             Required. The resource name of the
             HumanReviewConfig that the document will be
             reviewed with.
-        document (~.gcd_document.Document):
+        document (google.cloud.documentai_v1beta3.types.Document):
             The document that needs human review.
     """
 
+    inline_document = proto.Field(
+        proto.MESSAGE, number=4, oneof="source", message=gcd_document.Document,
+    )
+
     human_review_config = proto.Field(proto.STRING, number=1)
 
     document = proto.Field(proto.MESSAGE, number=2, message=gcd_document.Document,)
@@ -245,15 +330,55 @@ class ReviewDocumentOperationMetadata(proto.Message):
     method.
 
     Attributes:
-        state (~.document_processor_service.ReviewDocumentOperationMetadata.State):
+        state (google.cloud.documentai_v1beta3.types.ReviewDocumentOperationMetadata.State):
             Used only when Operation.done is false.
         state_message (str):
             A message providing more details about the
             current state of processing. For example, the
             error message if the operation is failed.
-        create_time (~.timestamp.Timestamp):
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
             The creation time of the operation.
-        update_time (~.timestamp.Timestamp):
+        update_time (google.protobuf.timestamp_pb2.Timestamp):
+            The last update time of the operation.
+        common_metadata (google.cloud.documentai_v1beta3.types.CommonOperationMetadata):
+            The basic metadata of the long running
+            operation.
+    """
+
+    class State(proto.Enum):
+        r"""State of the longrunning operation."""
+        STATE_UNSPECIFIED = 0
+        RUNNING = 1
+        CANCELLING = 2
+        SUCCEEDED = 3
+        FAILED = 4
+        CANCELLED = 5
+
+    state = proto.Field(proto.ENUM, number=1, enum=State,)
+
+    state_message = proto.Field(proto.STRING, number=2)
+
+    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
+
+    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp.Timestamp,)
+
+    common_metadata = proto.Field(
+        proto.MESSAGE, number=5, message="CommonOperationMetadata",
+    )
+
+
+class CommonOperationMetadata(proto.Message):
+    r"""The common metadata for long running operations.
+
+    Attributes:
+        state (google.cloud.documentai_v1beta3.types.CommonOperationMetadata.State):
+            The state of the operation.
+        state_message (str):
+            A message providing more details about the
+            current state of processing.
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
+            The creation time of the operation.
+        update_time (google.protobuf.timestamp_pb2.Timestamp):
             The last update time of the operation.
     """
 
