@@ -101,7 +101,25 @@ def test__get_default_mtls_endpoint():
 
 @pytest.mark.parametrize(
     "client_class",
-    [DocumentUnderstandingServiceClient, DocumentUnderstandingServiceAsyncClient],
+    [DocumentUnderstandingServiceClient, DocumentUnderstandingServiceAsyncClient,],
+)
+def test_document_understanding_service_client_from_service_account_info(client_class):
+    creds = credentials.AnonymousCredentials()
+    with mock.patch.object(
+        service_account.Credentials, "from_service_account_info"
+    ) as factory:
+        factory.return_value = creds
+        info = {"valid": True}
+        client = client_class.from_service_account_info(info)
+        assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
+
+        assert client.transport._host == "us-documentai.googleapis.com:443"
+
+
+@pytest.mark.parametrize(
+    "client_class",
+    [DocumentUnderstandingServiceClient, DocumentUnderstandingServiceAsyncClient,],
 )
 def test_document_understanding_service_client_from_service_account_file(client_class):
     creds = credentials.AnonymousCredentials()
@@ -110,17 +128,22 @@ def test_document_understanding_service_client_from_service_account_file(client_
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
-        assert client._transport._host == "us-documentai.googleapis.com:443"
+        assert client.transport._host == "us-documentai.googleapis.com:443"
 
 
 def test_document_understanding_service_client_get_transport_class():
     transport = DocumentUnderstandingServiceClient.get_transport_class()
-    assert transport == transports.DocumentUnderstandingServiceGrpcTransport
+    available_transports = [
+        transports.DocumentUnderstandingServiceGrpcTransport,
+    ]
+    assert transport in available_transports
 
     transport = DocumentUnderstandingServiceClient.get_transport_class("grpc")
     assert transport == transports.DocumentUnderstandingServiceGrpcTransport
@@ -179,7 +202,7 @@ def test_document_understanding_service_client_client_options(
             credentials_file=None,
             host="squid.clam.whelk",
             scopes=None,
-            ssl_channel_credentials=None,
+            client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
         )
@@ -195,7 +218,7 @@ def test_document_understanding_service_client_client_options(
                 credentials_file=None,
                 host=client.DEFAULT_ENDPOINT,
                 scopes=None,
-                ssl_channel_credentials=None,
+                client_cert_source_for_mtls=None,
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
             )
@@ -211,7 +234,7 @@ def test_document_understanding_service_client_client_options(
                 credentials_file=None,
                 host=client.DEFAULT_MTLS_ENDPOINT,
                 scopes=None,
-                ssl_channel_credentials=None,
+                client_cert_source_for_mtls=None,
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
             )
@@ -239,7 +262,7 @@ def test_document_understanding_service_client_client_options(
             credentials_file=None,
             host=client.DEFAULT_ENDPOINT,
             scopes=None,
-            ssl_channel_credentials=None,
+            client_cert_source_for_mtls=None,
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
         )
@@ -300,29 +323,25 @@ def test_document_understanding_service_client_mtls_env_auto(
             client_cert_source=client_cert_source_callback
         )
         with mock.patch.object(transport_class, "__init__") as patched:
-            ssl_channel_creds = mock.Mock()
-            with mock.patch(
-                "grpc.ssl_channel_credentials", return_value=ssl_channel_creds
-            ):
-                patched.return_value = None
-                client = client_class(client_options=options)
+            patched.return_value = None
+            client = client_class(client_options=options)
 
-                if use_client_cert_env == "false":
-                    expected_ssl_channel_creds = None
-                    expected_host = client.DEFAULT_ENDPOINT
-                else:
-                    expected_ssl_channel_creds = ssl_channel_creds
-                    expected_host = client.DEFAULT_MTLS_ENDPOINT
+            if use_client_cert_env == "false":
+                expected_client_cert_source = None
+                expected_host = client.DEFAULT_ENDPOINT
+            else:
+                expected_client_cert_source = client_cert_source_callback
+                expected_host = client.DEFAULT_MTLS_ENDPOINT
 
-                patched.assert_called_once_with(
-                    credentials=None,
-                    credentials_file=None,
-                    host=expected_host,
-                    scopes=None,
-                    ssl_channel_credentials=expected_ssl_channel_creds,
-                    quota_project_id=None,
-                    client_info=transports.base.DEFAULT_CLIENT_INFO,
-                )
+            patched.assert_called_once_with(
+                credentials=None,
+                credentials_file=None,
+                host=expected_host,
+                scopes=None,
+                client_cert_source_for_mtls=expected_client_cert_source,
+                quota_project_id=None,
+                client_info=transports.base.DEFAULT_CLIENT_INFO,
+            )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
     # GOOGLE_API_USE_CLIENT_CERTIFICATE value.
@@ -331,40 +350,31 @@ def test_document_understanding_service_client_mtls_env_auto(
     ):
         with mock.patch.object(transport_class, "__init__") as patched:
             with mock.patch(
-                "google.auth.transport.grpc.SslCredentials.__init__", return_value=None
+                "google.auth.transport.mtls.has_default_client_cert_source",
+                return_value=True,
             ):
                 with mock.patch(
-                    "google.auth.transport.grpc.SslCredentials.is_mtls",
-                    new_callable=mock.PropertyMock,
-                ) as is_mtls_mock:
-                    with mock.patch(
-                        "google.auth.transport.grpc.SslCredentials.ssl_credentials",
-                        new_callable=mock.PropertyMock,
-                    ) as ssl_credentials_mock:
-                        if use_client_cert_env == "false":
-                            is_mtls_mock.return_value = False
-                            ssl_credentials_mock.return_value = None
-                            expected_host = client.DEFAULT_ENDPOINT
-                            expected_ssl_channel_creds = None
-                        else:
-                            is_mtls_mock.return_value = True
-                            ssl_credentials_mock.return_value = mock.Mock()
-                            expected_host = client.DEFAULT_MTLS_ENDPOINT
-                            expected_ssl_channel_creds = (
-                                ssl_credentials_mock.return_value
-                            )
+                    "google.auth.transport.mtls.default_client_cert_source",
+                    return_value=client_cert_source_callback,
+                ):
+                    if use_client_cert_env == "false":
+                        expected_host = client.DEFAULT_ENDPOINT
+                        expected_client_cert_source = None
+                    else:
+                        expected_host = client.DEFAULT_MTLS_ENDPOINT
+                        expected_client_cert_source = client_cert_source_callback
 
-                        patched.return_value = None
-                        client = client_class()
-                        patched.assert_called_once_with(
-                            credentials=None,
-                            credentials_file=None,
-                            host=expected_host,
-                            scopes=None,
-                            ssl_channel_credentials=expected_ssl_channel_creds,
-                            quota_project_id=None,
-                            client_info=transports.base.DEFAULT_CLIENT_INFO,
-                        )
+                    patched.return_value = None
+                    client = client_class()
+                    patched.assert_called_once_with(
+                        credentials=None,
+                        credentials_file=None,
+                        host=expected_host,
+                        scopes=None,
+                        client_cert_source_for_mtls=expected_client_cert_source,
+                        quota_project_id=None,
+                        client_info=transports.base.DEFAULT_CLIENT_INFO,
+                    )
 
     # Check the case client_cert_source and ADC client cert are not provided.
     with mock.patch.dict(
@@ -372,24 +382,20 @@ def test_document_understanding_service_client_mtls_env_auto(
     ):
         with mock.patch.object(transport_class, "__init__") as patched:
             with mock.patch(
-                "google.auth.transport.grpc.SslCredentials.__init__", return_value=None
+                "google.auth.transport.mtls.has_default_client_cert_source",
+                return_value=False,
             ):
-                with mock.patch(
-                    "google.auth.transport.grpc.SslCredentials.is_mtls",
-                    new_callable=mock.PropertyMock,
-                ) as is_mtls_mock:
-                    is_mtls_mock.return_value = False
-                    patched.return_value = None
-                    client = client_class()
-                    patched.assert_called_once_with(
-                        credentials=None,
-                        credentials_file=None,
-                        host=client.DEFAULT_ENDPOINT,
-                        scopes=None,
-                        ssl_channel_credentials=None,
-                        quota_project_id=None,
-                        client_info=transports.base.DEFAULT_CLIENT_INFO,
-                    )
+                patched.return_value = None
+                client = client_class()
+                patched.assert_called_once_with(
+                    credentials=None,
+                    credentials_file=None,
+                    host=client.DEFAULT_ENDPOINT,
+                    scopes=None,
+                    client_cert_source_for_mtls=None,
+                    quota_project_id=None,
+                    client_info=transports.base.DEFAULT_CLIENT_INFO,
+                )
 
 
 @pytest.mark.parametrize(
@@ -420,7 +426,7 @@ def test_document_understanding_service_client_client_options_scopes(
             credentials_file=None,
             host=client.DEFAULT_ENDPOINT,
             scopes=["1", "2"],
-            ssl_channel_credentials=None,
+            client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
         )
@@ -454,7 +460,7 @@ def test_document_understanding_service_client_client_options_credentials_file(
             credentials_file="credentials.json",
             host=client.DEFAULT_ENDPOINT,
             scopes=None,
-            ssl_channel_credentials=None,
+            client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
         )
@@ -473,7 +479,7 @@ def test_document_understanding_service_client_client_options_from_dict():
             credentials_file=None,
             host="squid.clam.whelk",
             scopes=None,
-            ssl_channel_credentials=None,
+            client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
         )
@@ -493,7 +499,7 @@ def test_batch_process_documents(
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.batch_process_documents), "__call__"
+        type(client.transport.batch_process_documents), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/spam")
@@ -514,19 +520,40 @@ def test_batch_process_documents_from_dict():
     test_batch_process_documents(request_type=dict)
 
 
+def test_batch_process_documents_empty_call():
+    # This test is a coverage failsafe to make sure that totally empty calls,
+    # i.e. request == None and no flattened fields passed, work.
+    client = DocumentUnderstandingServiceClient(
+        credentials=credentials.AnonymousCredentials(), transport="grpc",
+    )
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(
+        type(client.transport.batch_process_documents), "__call__"
+    ) as call:
+        client.batch_process_documents()
+        call.assert_called()
+        _, args, _ = call.mock_calls[0]
+
+        assert args[0] == document_understanding.BatchProcessDocumentsRequest()
+
+
 @pytest.mark.asyncio
-async def test_batch_process_documents_async(transport: str = "grpc_asyncio"):
+async def test_batch_process_documents_async(
+    transport: str = "grpc_asyncio",
+    request_type=document_understanding.BatchProcessDocumentsRequest,
+):
     client = DocumentUnderstandingServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = document_understanding.BatchProcessDocumentsRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.batch_process_documents), "__call__"
+        type(client.transport.batch_process_documents), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
@@ -539,12 +566,17 @@ async def test_batch_process_documents_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == document_understanding.BatchProcessDocumentsRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, future.Future)
 
 
+@pytest.mark.asyncio
+async def test_batch_process_documents_async_from_dict():
+    await test_batch_process_documents_async(request_type=dict)
+
+
 def test_batch_process_documents_field_headers():
     client = DocumentUnderstandingServiceClient(
         credentials=credentials.AnonymousCredentials(),
@@ -557,7 +589,7 @@ def test_batch_process_documents_field_headers():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.batch_process_documents), "__call__"
+        type(client.transport.batch_process_documents), "__call__"
     ) as call:
         call.return_value = operations_pb2.Operation(name="operations/op")
 
@@ -586,7 +618,7 @@ async def test_batch_process_documents_field_headers_async():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.batch_process_documents), "__call__"
+        type(client.transport.batch_process_documents), "__call__"
     ) as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             operations_pb2.Operation(name="operations/op")
@@ -611,7 +643,7 @@ def test_batch_process_documents_flattened():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.batch_process_documents), "__call__"
+        type(client.transport.batch_process_documents), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/op")
@@ -658,7 +690,7 @@ async def test_batch_process_documents_flattened_async():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.batch_process_documents), "__call__"
+        type(client.transport.batch_process_documents), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/op")
@@ -713,9 +745,7 @@ def test_process_document(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._transport.process_document), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.process_document), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = document.Document(
             mime_type="mime_type_value", text="text_value", uri="uri_value",
@@ -730,6 +760,7 @@ def test_process_document(
         assert args[0] == document_understanding.ProcessDocumentRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, document.Document)
 
     assert response.mime_type == "mime_type_value"
@@ -741,20 +772,37 @@ def test_process_document_from_dict():
     test_process_document(request_type=dict)
 
 
+def test_process_document_empty_call():
+    # This test is a coverage failsafe to make sure that totally empty calls,
+    # i.e. request == None and no flattened fields passed, work.
+    client = DocumentUnderstandingServiceClient(
+        credentials=credentials.AnonymousCredentials(), transport="grpc",
+    )
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.process_document), "__call__") as call:
+        client.process_document()
+        call.assert_called()
+        _, args, _ = call.mock_calls[0]
+
+        assert args[0] == document_understanding.ProcessDocumentRequest()
+
+
 @pytest.mark.asyncio
-async def test_process_document_async(transport: str = "grpc_asyncio"):
+async def test_process_document_async(
+    transport: str = "grpc_asyncio",
+    request_type=document_understanding.ProcessDocumentRequest,
+):
     client = DocumentUnderstandingServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = document_understanding.ProcessDocumentRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.process_document), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.process_document), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             document.Document(mime_type="mime_type_value", text="text_value",)
@@ -766,7 +814,7 @@ async def test_process_document_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == document_understanding.ProcessDocumentRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, document.Document)
@@ -776,6 +824,11 @@ async def test_process_document_async(transport: str = "grpc_asyncio"):
     assert response.text == "text_value"
 
 
+@pytest.mark.asyncio
+async def test_process_document_async_from_dict():
+    await test_process_document_async(request_type=dict)
+
+
 def test_process_document_field_headers():
     client = DocumentUnderstandingServiceClient(
         credentials=credentials.AnonymousCredentials(),
@@ -787,9 +840,7 @@ def test_process_document_field_headers():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._transport.process_document), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.process_document), "__call__") as call:
         call.return_value = document.Document()
 
         client.process_document(request)
@@ -816,9 +867,7 @@ async def test_process_document_field_headers_async():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.process_document), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.process_document), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(document.Document())
 
         await client.process_document(request)
@@ -869,7 +918,7 @@ def test_transport_instance():
         credentials=credentials.AnonymousCredentials(),
     )
     client = DocumentUnderstandingServiceClient(transport=transport)
-    assert client._transport is transport
+    assert client.transport is transport
 
 
 def test_transport_get_channel():
@@ -908,7 +957,7 @@ def test_transport_grpc_default():
         credentials=credentials.AnonymousCredentials(),
     )
     assert isinstance(
-        client._transport, transports.DocumentUnderstandingServiceGrpcTransport,
+        client.transport, transports.DocumentUnderstandingServiceGrpcTransport,
     )
 
 
@@ -1002,6 +1051,53 @@ def test_document_understanding_service_transport_auth_adc():
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.DocumentUnderstandingServiceGrpcTransport,
+        transports.DocumentUnderstandingServiceGrpcAsyncIOTransport,
+    ],
+)
+def test_document_understanding_service_grpc_transport_client_cert_source_for_mtls(
+    transport_class,
+):
+    cred = credentials.AnonymousCredentials()
+
+    # Check ssl_channel_credentials is used if provided.
+    with mock.patch.object(transport_class, "create_channel") as mock_create_channel:
+        mock_ssl_channel_creds = mock.Mock()
+        transport_class(
+            host="squid.clam.whelk",
+            credentials=cred,
+            ssl_channel_credentials=mock_ssl_channel_creds,
+        )
+        mock_create_channel.assert_called_once_with(
+            "squid.clam.whelk:443",
+            credentials=cred,
+            credentials_file=None,
+            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            ssl_credentials=mock_ssl_channel_creds,
+            quota_project_id=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+    # Check if ssl_channel_credentials is not provided, then client_cert_source_for_mtls
+    # is used.
+    with mock.patch.object(transport_class, "create_channel", return_value=mock.Mock()):
+        with mock.patch("grpc.ssl_channel_credentials") as mock_ssl_cred:
+            transport_class(
+                credentials=cred,
+                client_cert_source_for_mtls=client_cert_source_callback,
+            )
+            expected_cert, expected_key = client_cert_source_callback()
+            mock_ssl_cred.assert_called_once_with(
+                certificate_chain=expected_cert, private_key=expected_key
+            )
+
+
 def test_document_understanding_service_host_no_port():
     client = DocumentUnderstandingServiceClient(
         credentials=credentials.AnonymousCredentials(),
@@ -1009,7 +1105,7 @@ def test_document_understanding_service_host_no_port():
             api_endpoint="us-documentai.googleapis.com"
         ),
     )
-    assert client._transport._host == "us-documentai.googleapis.com:443"
+    assert client.transport._host == "us-documentai.googleapis.com:443"
 
 
 def test_document_understanding_service_host_with_port():
@@ -1019,11 +1115,11 @@ def test_document_understanding_service_host_with_port():
             api_endpoint="us-documentai.googleapis.com:8000"
         ),
     )
-    assert client._transport._host == "us-documentai.googleapis.com:8000"
+    assert client.transport._host == "us-documentai.googleapis.com:8000"
 
 
 def test_document_understanding_service_grpc_transport_channel():
-    channel = grpc.insecure_channel("http://localhost/")
+    channel = grpc.secure_channel("http://localhost/", grpc.local_channel_credentials())
 
     # Check that channel is used if provided.
     transport = transports.DocumentUnderstandingServiceGrpcTransport(
@@ -1031,10 +1127,11 @@ def test_document_understanding_service_grpc_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 def test_document_understanding_service_grpc_asyncio_transport_channel():
-    channel = aio.insecure_channel("http://localhost/")
+    channel = aio.secure_channel("http://localhost/", grpc.local_channel_credentials())
 
     # Check that channel is used if provided.
     transport = transports.DocumentUnderstandingServiceGrpcAsyncIOTransport(
@@ -1042,8 +1139,11 @@ def test_document_understanding_service_grpc_asyncio_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
+# Remove this test when deprecated arguments (api_mtls_endpoint, client_cert_source) are
+# removed from grpc/grpc_asyncio transport constructor.
 @pytest.mark.parametrize(
     "transport_class",
     [
@@ -1058,7 +1158,7 @@ def test_document_understanding_service_transport_channel_mtls_with_client_cert_
         "grpc.ssl_channel_credentials", autospec=True
     ) as grpc_ssl_channel_cred:
         with mock.patch.object(
-            transport_class, "create_channel", autospec=True
+            transport_class, "create_channel"
         ) as grpc_create_channel:
             mock_ssl_cred = mock.Mock()
             grpc_ssl_channel_cred.return_value = mock_ssl_cred
@@ -1087,10 +1187,17 @@ def test_document_understanding_service_transport_channel_mtls_with_client_cert_
                 scopes=("https://www.googleapis.com/auth/cloud-platform",),
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
             )
             assert transport.grpc_channel == mock_grpc_channel
+            assert transport._ssl_channel_credentials == mock_ssl_cred
 
 
+# Remove this test when deprecated arguments (api_mtls_endpoint, client_cert_source) are
+# removed from grpc/grpc_asyncio transport constructor.
 @pytest.mark.parametrize(
     "transport_class",
     [
@@ -1108,7 +1215,7 @@ def test_document_understanding_service_transport_channel_mtls_with_adc(
         ssl_credentials=mock.PropertyMock(return_value=mock_ssl_cred),
     ):
         with mock.patch.object(
-            transport_class, "create_channel", autospec=True
+            transport_class, "create_channel"
         ) as grpc_create_channel:
             mock_grpc_channel = mock.Mock()
             grpc_create_channel.return_value = mock_grpc_channel
@@ -1129,6 +1236,10 @@ def test_document_understanding_service_transport_channel_mtls_with_adc(
                 scopes=("https://www.googleapis.com/auth/cloud-platform",),
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
             )
             assert transport.grpc_channel == mock_grpc_channel
 
@@ -1137,7 +1248,7 @@ def test_document_understanding_service_grpc_lro_client():
     client = DocumentUnderstandingServiceClient(
         credentials=credentials.AnonymousCredentials(), transport="grpc",
     )
-    transport = client._transport
+    transport = client.transport
 
     # Ensure that we have a api-core operations client.
     assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
@@ -1150,7 +1261,7 @@ def test_document_understanding_service_grpc_lro_async_client():
     client = DocumentUnderstandingServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport="grpc_asyncio",
     )
-    transport = client._client._transport
+    transport = client.transport
 
     # Ensure that we have a api-core operations client.
     assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
@@ -1159,6 +1270,109 @@ def test_document_understanding_service_grpc_lro_async_client():
     assert transport.operations_client is transport.operations_client
 
 
+def test_common_billing_account_path():
+    billing_account = "squid"
+
+    expected = "billingAccounts/{billing_account}".format(
+        billing_account=billing_account,
+    )
+    actual = DocumentUnderstandingServiceClient.common_billing_account_path(
+        billing_account
+    )
+    assert expected == actual
+
+
+def test_parse_common_billing_account_path():
+    expected = {
+        "billing_account": "clam",
+    }
+    path = DocumentUnderstandingServiceClient.common_billing_account_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = DocumentUnderstandingServiceClient.parse_common_billing_account_path(path)
+    assert expected == actual
+
+
+def test_common_folder_path():
+    folder = "whelk"
+
+    expected = "folders/{folder}".format(folder=folder,)
+    actual = DocumentUnderstandingServiceClient.common_folder_path(folder)
+    assert expected == actual
+
+
+def test_parse_common_folder_path():
+    expected = {
+        "folder": "octopus",
+    }
+    path = DocumentUnderstandingServiceClient.common_folder_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = DocumentUnderstandingServiceClient.parse_common_folder_path(path)
+    assert expected == actual
+
+
+def test_common_organization_path():
+    organization = "oyster"
+
+    expected = "organizations/{organization}".format(organization=organization,)
+    actual = DocumentUnderstandingServiceClient.common_organization_path(organization)
+    assert expected == actual
+
+
+def test_parse_common_organization_path():
+    expected = {
+        "organization": "nudibranch",
+    }
+    path = DocumentUnderstandingServiceClient.common_organization_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = DocumentUnderstandingServiceClient.parse_common_organization_path(path)
+    assert expected == actual
+
+
+def test_common_project_path():
+    project = "cuttlefish"
+
+    expected = "projects/{project}".format(project=project,)
+    actual = DocumentUnderstandingServiceClient.common_project_path(project)
+    assert expected == actual
+
+
+def test_parse_common_project_path():
+    expected = {
+        "project": "mussel",
+    }
+    path = DocumentUnderstandingServiceClient.common_project_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = DocumentUnderstandingServiceClient.parse_common_project_path(path)
+    assert expected == actual
+
+
+def test_common_location_path():
+    project = "winkle"
+    location = "nautilus"
+
+    expected = "projects/{project}/locations/{location}".format(
+        project=project, location=location,
+    )
+    actual = DocumentUnderstandingServiceClient.common_location_path(project, location)
+    assert expected == actual
+
+
+def test_parse_common_location_path():
+    expected = {
+        "project": "scallop",
+        "location": "abalone",
+    }
+    path = DocumentUnderstandingServiceClient.common_location_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = DocumentUnderstandingServiceClient.parse_common_location_path(path)
+    assert expected == actual
+
+
 def test_client_withDEFAULT_CLIENT_INFO():
     client_info = gapic_v1.client_info.ClientInfo()
 
